@@ -1,7 +1,9 @@
 #!/usr/bin/env bash
 
 readonly ROOT_DIR=$(dirname $0)/..
-source ${ROOT_DIR}/vendor/knative.dev/test-infra/scripts/library.sh
+
+# shellcheck disable=SC1091,SC1090
+source "${ROOT_DIR}/vendor/knative.dev/hack/library.sh"
 
 set -o errexit
 set -o nounset
@@ -10,20 +12,25 @@ set -o pipefail
 cd ${ROOT_DIR}
 
 # This controls the knative release version we track.
-KN_VERSION="release-0.17"
+KN_VERSION="release-0.19"
 
 # Controls the version of OCP related dependencies.
-OCP_VERSION="release-4.5"
+OCP_VERSION="release-4.6"
 
 # The list of dependencies that we track at HEAD and periodically
 # float forward in this repository.
 FLOATING_DEPS=(
-  "github.com/openshift/api@${OCP_VERSION}"
+  "github.com/openshift/api@release-4.7"
+  "github.com/openshift/client-go@${OCP_VERSION}"
+  "github.com/operator-framework/operator-lifecycle-manager@${OCP_VERSION}"
 
+  "knative.dev/eventing-kafka@${KN_VERSION}"
+  "knative.dev/eventing@${KN_VERSION}"
+  "knative.dev/hack@${KN_VERSION}"
   "knative.dev/networking@${KN_VERSION}"
+  "knative.dev/operator@${KN_VERSION}"
   "knative.dev/pkg@${KN_VERSION}"
   "knative.dev/serving@${KN_VERSION}"
-  "knative.dev/test-infra@${KN_VERSION}"
 )
 
 # Parse flags to determine if we need to update our floating deps.
@@ -46,6 +53,15 @@ fi
 go mod tidy
 go mod vendor
 
+# Remove files conflicting due to logr.
+rm -f vendor/knative.dev/pkg/test/logging/tlogger.go \
+  vendor/knative.dev/pkg/test/logging/zapr.go \
+  vendor/knative.dev/pkg/test/logging/sugar.go \
+  vendor/knative.dev/pkg/test/logging/error.go \
+  vendor/knative.dev/pkg/test/logging/spew_encoder.go \
+  vendor/knative.dev/pkg/test/logging/memory_encoder.go \
+  vendor/knative.dev/pkg/test/logging/logger.go
+
 # Remove unnecessary files.
 find vendor/ \( -name "OWNERS" \
   -o -name "OWNERS_ALIASES" \
@@ -53,5 +69,4 @@ find vendor/ \( -name "OWNERS" \
   -o -name "BUILD.bazel" \
   -o -name "*_test.go" \) -exec rm -fv {} +
 
-# Add permission for shell scripts
 find vendor -type f -name '*.sh' -exec chmod +x {} +
